@@ -5,11 +5,11 @@
  * @date     Wed Dec 04, 2002 01:11
  * @brief    SCEW usage example
  *
- * $Id: scew_print.c,v 1.18 2003/07/16 21:55:21 aleix Exp $
+ * $Id: scew_print.c,v 1.20 2004/01/29 22:38:33 aleix Exp $
  *
  * @if copyright
  *
- * Copyright (C) 2002, 2003 Aleix Conchillo Flaque
+ * Copyright (C) 2002, 2003, 2004 Aleix Conchillo Flaque
  *
  * SCEW is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -23,7 +23,7 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
  *
  * @endif
  *
@@ -35,7 +35,7 @@
  * You will probably need to change this include to <scew/scew.h> in you
  * program.
  */
-#include "scew.h"
+#include <scew/scew.h>
 
 #include <stdio.h>
 
